@@ -17,9 +17,12 @@ setMethod( "format", "hash",
 
     ret <- paste( "<hash> containing ", length(x), " key-value pairs.\n", sep="" )
 
-
     for ( k in keys(x) ) {
-      vals <- paste( format( x[[k]], indent=indent ), collapse = " " ) 
+      # vals <-  paste( format( x[[k]], indent=indent ), collapse = " " )  
+      # THERE ARE SOME CASES WHERE FORMAT DOESN'T WORK, WE TRAP THESE.
+      vals <- try( paste( format( x[[k]], indent=indent ), collapse = " " ), silent=T )  
+      if( inherits( vals, "try-error" ) ) vals <- paste( as.character( x[[k]] ), collapse=", " )
+      
       ret <-  paste( ret, indent2, k, " : ", vals, "\n", sep=""  )    
     }
 
