@@ -4,7 +4,7 @@
 # -----------------------------------------------------------------------------
 setGeneric( "keys", function(x) standardGeneric("keys") )
 setMethod( "keys" , "hash" ,
-	function(x) ls(x@env)
+	function(x) ls(x@.Data)
 )
 
 names.hash <- function(x) keys(x)
